[PATCH] D32268: Use WeakVH instead of WeakTrackingVH in AliasSetTracker's UnkownInsts

Sanjoy Das via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Apr 19 21:47:45 PDT 2017


sanjoy created this revision.
Herald added a subscriber: mcrosier.

In cases where an instruction (a call site, say) is RAUW'ed with some
other value (this is possible via the `returned` attribute, amongst
other things), we want the slot in UnknownInsts to point to the
original Instruction we wanted to track, not the value it got replaced
by.

Fixes PR32587.


https://reviews.llvm.org/D32268

Files:
  include/llvm/Analysis/AliasSetTracker.h
  test/Analysis/AliasSet/unknown-inst-tracking.ll


Index: test/Analysis/AliasSet/unknown-inst-tracking.ll
===================================================================
--- /dev/null
+++ test/Analysis/AliasSet/unknown-inst-tracking.ll
@@ -0,0 +1,23 @@
+; RUN: opt -S -licm -loop-unswitch < %s | FileCheck %s
+
+ at global = external global i32
+
+declare i32 @f_1(i8, i32 returned)
+
+define i32 @f_0() {
+; CHECK-LABEL: @f_0(
+bb:
+  br label %bb1
+
+bb1:                                              ; preds = %bb3, %bb
+  %tmp = load i32, i32* @global
+  %tmp2 = select i1 false, i16 1, i16 0
+  br label %bb3
+
+bb3:                                              ; preds = %bb3, %bb1
+  %tmp4 = phi i8 [ 0, %bb1 ], [ %tmp6, %bb3 ]
+  %tmp5 = icmp eq i16 %tmp2, 0
+  %tmp6 = select i1 %tmp5, i8 %tmp4, i8 1
+  %tmp7 = tail call i32 @f_1(i8 %tmp6, i32 1)
+  br i1 false, label %bb1, label %bb3
+}
Index: include/llvm/Analysis/AliasSetTracker.h
===================================================================
--- include/llvm/Analysis/AliasSetTracker.h
+++ include/llvm/Analysis/AliasSetTracker.h
@@ -121,10 +121,10 @@
   AliasSet *Forward;
 
   /// All instructions without a specific address in this alias set.
   /// In rare cases this vector can have a null'ed out WeakTrackingVH
   /// instances (can happen if some other loop pass deletes an
   /// instruction in this list).
-  std::vector<WeakTrackingVH> UnknownInsts;
+  std::vector<WeakVH> UnknownInsts;
 
   /// Number of nodes pointing to this AliasSet plus the number of AliasSets
   /// forwarding to it.


-------------- next part --------------
@@ -121,10 +121,10 @@
 
   /// All instructions without a specific address in this alias set.
-  /// In rare cases this vector can have a null'ed out WeakTrackingVH
+  /// In rare cases this vector can have a null'ed out WeakVH
   /// instances (can happen if some other loop pass deletes an
   /// instruction in this list).
A non-text attachment was scrubbed...
Name: D32268.95883.patch
Type: text/x-patch
Size: 1587 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20170420/8a746bc3/attachment.bin>


More information about the llvm-commits mailing list